@@ -38,7 +38,7 @@ function submitForms()
     var missing = 0;
     for(var i = 0; i < checkboxes.length; i++){
         if(checkboxes[i].checked == true && checkboxes[i].disabled == false){
-            var num = checkboxes[i].name.match(/d+$/)[0];
+            var num = checkboxes[i].name.match(/\d+$/)[0];
             for(var x = 0; x < window.inputs.length; x++){
                 if(document.getElementsByName(window.inputs[x]+num)[0].value == ""){
                      document.getElementById(window.inputs[x]+num+"req").style.display="block";
@@ -58,10 +58,10 @@ function submitForms()
     // make sure that there is no repeated data
     for(var i = 0; i<checkboxes.length; i++){
         if(checkboxes[i].checked == true){
-            var numi = checkboxes[i].name.match(/d+$/)[0];
+            var numi = checkboxes[i].name.match(/\d+$/)[0];
             for(var x = i+1;x<checkboxes.length;x++){
                 if(checkboxes[x].checked == true){
-                    var numx = checkboxes[x].name.match(/d+$/)[0];
+                    var numx = checkboxes[x].name.match(/\d+$/)[0];
                     if($("#hostname"+numi).val() == $("#hostname"+numx).val()){
                         alert('Hostnames must be unique');
                         return false;
@@ -76,7 +76,7 @@ function submitForms()
         for(var i = 0; i < checkboxes.length; i++){
             if(checkboxes[i].checked == true && checkboxes[i].disabled == false){
                 //derive form name and submit to be input into db
-                var num = checkboxes[i].name.match(/d+$/)[0];
+                var num = checkboxes[i].name.match(/\d+$/)[0];
                 var form_name = "form".concat(num);
                 var form = document.getElementsByName(form_name)[0];
                 var serializedData = $("#form"+num).serialize();
@@ -171,7 +171,7 @@ function cumulative_stat_check(){
             for(var i=0;i<data.jobs.length;i++){
                 for(var j=0;j<checkboxes.length;j++){
                     if(checkboxes[j].value == data.jobs[i].name){
-                        var num = checkboxes[j].name.match(/d+$/)[0];
+                        var num = checkboxes[j].name.match(/\d+$/)[0];
                     }
                 }
                 // display the status of the job
@@ -242,7 +242,7 @@ function globalOS(os){
     var checkboxes = document.getElementsByClassName("check");
     for( var i = 0;i<checkboxes.length;i++){
         if(checkboxes[i].checked == true && checkboxes[i].disabled == false){
-            var num = checkboxes[i].name.match(/d+$/)[0];
+            var num = checkboxes[i].name.match(/\d+$/)[0];
             $("#os"+num).val($(os).val());
         }
     }
@@ -252,7 +252,7 @@ function globalProf(prof){
     var checkboxes = document.getElementsByClassName("check");
     for( var i = 0;i<checkboxes.length;i++){
         if(checkboxes[i].checked == true && checkboxes[i].disabled == false){
-            var num = checkboxes[i].name.match(/d+$/)[0];
+            var num = checkboxes[i].name.match(/\d+$/)[0];
             $("#app_prof"+num).val($(prof).val());
         }
     }
@@ -267,7 +267,7 @@ function checkAll(){
 }
 
 function deleteJob(del){
-    var num = del.name.match(/d+$/)[0];
+    var num = del.name.match(/\d+$/)[0];
     // need to delete machine from the machine table
     // keeping the completed job in the job_tracker table however for documentation purposes
     $.ajax({
